@@ -10,6 +10,8 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "allocateSO3CoeffsSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abc4a61da919ae37b0a03d23df2461224", null ],
     [ "allocateWignerMatricesSpace", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a8b4f9cfa31af0209e934d2404967ed4a", null ],
     [ "centreMapOnCOM", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a80ff45ef40549fb6a1d80b70865fc807", null ],
+    [ "computeGroupElementsForGroup", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a847c744261a8dc721efc4d6900cdd557", null ],
+    [ "computeGroupElementsForGroup", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a4f4bb25b05f273a41bce8205f9058717", null ],
     [ "computeOptimalTranslation", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aabab21be3199e734780b5ae8408b9fd5", null ],
     [ "computePdbRotationCentre", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa48fc72e389e663248d27eedbbf32314", null ],
     [ "computeRotatedSH", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a569bda712a5ecedb260ac790db90efef", null ],
@@ -56,9 +58,8 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "getNoRecommendedSymmetryAxes", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad1fdcd9bdebc2900748821c5b3cb53cc", null ],
     [ "getOctahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a14c4d6044c5174afa8a0984025c45436", null ],
     [ "getOverlayRotationFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ad409e4556676857224d1f5e00e5b7911", null ],
-    [ "getPredictedIcosahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a79524f817dacbd30c4a76d7705d1332f", null ],
-    [ "getPredictedOctahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#ae97b54a34689c1dceae47a5e8e94bbb0", null ],
-    [ "getPredictedTetrahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a931aa4c10c426c3b8041bd4e838b0678", null ],
+    [ "getPredictedIcosahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a73f96f10f0eb19f3fed57d956f75955e", null ],
+    [ "getPredictedOctahedralSymmetriesList", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abf0fecb2f515e41608cb1f4640691d74", null ],
     [ "getRealEMatrixValuesForLM", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aa757f9d32ebe20435661599652fd30fa", null ],
     [ "getRealRotFunction", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a8bc5fbad1079d42bfa73913a9e2df619", null ],
     [ "getRealSO3Coeffs", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a30eac0ab5b69c1b7190d6e56571ba8b8", null ],
@@ -99,6 +100,7 @@ var class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data =
     [ "maskMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a0122be830893f5d82bab742be54d1ee7", null ],
     [ "normaliseEMatrixValue", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aceb19c915cebcef22c085cc6619cc472", null ],
     [ "normaliseMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a255bdb77824ce0fddc2454d5823219e1", null ],
+    [ "optimiseDihedralAngleFromAngleAxis", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#aec8b3ae9e7ccaeaa8abeda92571a1d50", null ],
     [ "processInternalMap", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#afcb4202e9ffea1b99c59f73faf06d899", null ],
     [ "readInMAP", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#a07fb6e354dcd90dc70f8b4fa8bba0c33", null ],
     [ "readInPDB", "class_pro_s_h_a_d_e__internal__data_1_1_pro_s_h_a_d_e__data.html#abd1c1b3588308f775da5c8aeba3f3e78", null ],
