@@ -19,8 +19,8 @@
 
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.5.4
-    \date      MAR 2021
+    \version   0.7.5.1
+    \date      JAN 2021
 */
 
 //==================================================== ProSHADE
@@ -138,27 +138,15 @@ int main ( int argc, char **argv )
     }
     
     //================================================ Expected output
-//  Detected symmetry: O-0 with axes:
-//  Symmetry axis number 0: Fold 4 XYZ: 0 ; 0 ; 1 Angle (radians): 1.5708 and axis peak: 0.988541
-//  Symmetry axis number 1: Fold 4 XYZ: 0.147863 ; -0.989008 ; 0 Angle (radians): 1.5708 and axis peak: 0.37019
-//  Symmetry axis number 2: Fold 4 XYZ: 0.989008 ; 0.147863 ; 0 Angle (radians): 1.5708 and axis peak: 0.36993
-//  Symmetry axis number 3: Fold 3 XYZ: 0.656373 ; -0.485635 ; 0.57735 Angle (radians): 2.0944 and axis peak: 0.371807
-//  Symmetry axis number 4: Fold 3 XYZ: 0.656373 ; -0.485635 ; -0.57735 Angle (radians): 2.0944 and axis peak: 0.369289
-//  Symmetry axis number 5: Fold 3 XYZ: -0.485635 ; -0.656373 ; 0.57735 Angle (radians): 2.0944 and axis peak: 0.371268
-//  Symmetry axis number 6: Fold 3 XYZ: -0.485635 ; -0.656373 ; -0.57735 Angle (radians): 2.0944 and axis peak: 0.369423
-//  Symmetry axis number 7: Fold 2 XYZ: 0.104555 ; -0.699334 ; 0.707107 Angle (radians): 3.14159 and axis peak: 0.371559
-//  Symmetry axis number 8: Fold 2 XYZ: 0.803889 ; -0.594779 ; 0 Angle (radians): 3.14159 and axis peak: 0.630171
-//  Symmetry axis number 9: Fold 2 XYZ: 0.699334 ; 0.104555 ; 0.707107 Angle (radians): 3.14159 and axis peak: 0.370128
-//  Symmetry axis number 10: Fold 2 XYZ: 0.104555 ; -0.699334 ; -0.707107 Angle (radians): 3.14159 and axis peak: 0.367663
-//  Symmetry axis number 11: Fold 2 XYZ: 0.699334 ; 0.104555 ; -0.707107 Angle (radians): 3.14159 and axis peak: 0.368708
-//  Symmetry axis number 12: Fold 2 XYZ: -0.594779 ; -0.803889 ; 0 Angle (radians): 3.14159 and axis peak: 0.629292
+//  Detected symmetry: C-12 with axes:
+//  Symmetry axis number 0: Fold 12 XYZ: 0 ; 0 ; 1 Angle (radians): 0.523599 and axis peak: 0.964052
     
     //================================================ Find all C axes
     std::vector < std::vector< proshade_double > > allCs = settings->allDetectedCAxes;
     std::cout << "Found total of " << allCs.size() << " cyclic symmetry axes." << std::endl;
     
     //================================================ Expected output
-//  Found total of 54 cyclic symmetry axes.
+//  Found total of 35 cyclic symmetry axes.
     
     //================================================ Release the object
     delete simpleSym;
@@ -208,8 +196,8 @@ int main ( int argc, char **argv )
     
     //================================================ Expected output
 //  Detected symmetry: D-4 as requested. The axes are:
-//  Symmetry axis number 0: Fold 4 XYZ: 0 ; 0 ; 1 Angle (radians): 1.5708 and axis peak: 0.986754
-//  Symmetry axis number 1: Fold 2 XYZ: -0.596465 ; 0.802192 ; 0.0267738 Angle (radians): 3.14159 and axis peak: 0.640231
+//  Symmetry axis number 0: Fold 4 XYZ: 0 ; 0 ; 1 Angle (radians): 1.5708 and axis peak: 0.996923
+//  Symmetry axis number 1: Fold 2 XYZ: 0.802192 ; 0.596465 ; 0.0267742 Angle (radians): 3.14159 and axis peak: 0.640755
     
     
     //  NOTE: To get all the point group elements, one needs to supply the list of all cyclic point groups which comprise the
@@ -280,14 +268,14 @@ int main ( int argc, char **argv )
     
     //================================================ Print results
     std::cout << "Point group D" << allCs.at(bestDAxesList.at(0))[0] << "-" << allCs.at(bestDAxesList.at(1))[0] << " has been found to have " << groupElements.size() << " group elements, with the first element (excluding the identity one) having rotation matrix:" << std::fixed << std::setprecision(2) << std::showpos << std::endl;
-    std::cout << groupElements.at(0).at(0) << " | " << groupElements.at(0).at(1) << " | " << groupElements.at(0).at(2) << std::endl;
-    std::cout << groupElements.at(0).at(3) << " | " << groupElements.at(0).at(4) << " | " << groupElements.at(0).at(5) << std::endl;
-    std::cout << groupElements.at(0).at(6) << " | " << groupElements.at(0).at(7) << " | " << groupElements.at(0).at(8) << std::endl << std::endl;
+    std::cout << groupElements.at(1).at(0) << " | " << groupElements.at(1).at(1) << " | " << groupElements.at(1).at(2) << std::endl;
+    std::cout << groupElements.at(1).at(3) << " | " << groupElements.at(1).at(4) << " | " << groupElements.at(1).at(5) << std::endl;
+    std::cout << groupElements.at(1).at(6) << " | " << groupElements.at(1).at(7) << " | " << groupElements.at(1).at(8) << std::endl << std::endl;
         
     //================================================ Expected output
 //  Point group D4-2 has been found to have 8 group elements, with the first element (excluding the identity one) having rotation matrix:
-//  +0.00 | +1.00 | +0.00
-//  -1.00 | +0.00 | +0.00
+//  +0.00 | -1.00 | +0.00
+//  +1.00 | +0.00 | +0.00
 //  +0.00 | +0.00 | +1.00
  
     //================================================ Release the settings and runProshade objects
