@@ -15,8 +15,8 @@
  
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.5.4
-    \date      MAR 2021
+    \version   0.7.5.1
+    \date      JAN 2021
  */
 
 //==================================================== ProSHADE
@@ -71,9 +71,6 @@ extern "C" {
 
 #pragma GCC diagnostic pop
 
-//==================================================== GetOpt port (BSD License, works on Windows as well as linux)
-#include <getopt_port/getopt_port.h>
-
 //==================================================== Overinclusion protection
 #ifndef __PROSHADE_SETTINGS__
 #define __PROSHADE_SETTINGS__
@@ -202,8 +199,7 @@ public: // maybe make this protected?
     void determineBandwidth                           ( proshade_unsign circumference );
     void determineSphereDistances                     ( proshade_single maxMapRange );
     void determineIntegrationOrder                    ( proshade_single maxMapRange );
-    void determineAllSHValues                         ( proshade_unsign xDim, proshade_unsign yDim, proshade_unsign zDim, proshade_double xDimAngs,
-                                                        proshade_double yDimAngs, proshade_double zDimAngs );
+    void determineAllSHValues                         ( proshade_unsign xDim, proshade_unsign yDim, proshade_unsign zDim );
     void setVariablesLeftOnAuto                       ( void );
     
 public:
