@@ -1,7 +1,7 @@
 /*! \file pyProSHADE_bindings.cpp
     \brief This file contains and combines the PyBind11 bindings for the ProSHADE python module.
     
-    This file defines the python module for PyBind11, sets the main values and then includes all of the bindings from the other files.
+    ...
     
     Copyright by Michal Tykac and individual contributors. All rights reserved.
 
@@ -14,14 +14,10 @@
  
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.5.4
-    \date      MAR 2021
+    \version   0.7.5.1
+    \date      JAN 2021
  */
 
-//==================================================== Include getopt_port for python
-#include <getopt_port/getopt_port.h>
-#include <getopt_port/getopt_port.c>
-
 //==================================================== Include ProSHADE
 #include "ProSHADE.hpp"
 
