@@ -1,7 +1,7 @@
 /*! \file pyProSHADE.cpp
-    \brief This file contains the PyBind11 bindings for the ProSHADE_internal_distances namespace.
+    \brief This file contains the PyBind11 bindings for the ProSHADE_settings class.
     
-    This file provides the bindings for the ProSHADE_internal_distances namespace functions.
+    ...
     
     Copyright by Michal Tykac and individual contributors. All rights reserved.
 
@@ -14,8 +14,8 @@
  
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.5.4
-    \date      MAR 2021
+    \version   0.7.5.1
+    \date      JAN 2021
  */
 
 //==================================================== Include PyBind11 header
